@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Reports::Web::Controller::Tapper::Preconditions::Id::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Reports::Web::Controller::Tapper::Preconditions::Id::VERSION = '4.0.4';
+  $Tapper::Reports::Web::Controller::Tapper::Preconditions::Id::VERSION = '4.1.0';
 }
 
 use strict;
@@ -14,15 +14,14 @@ use parent 'Tapper::Reports::Web::Controller::Base';
 sub index :Path :Args(1)
 {
         my ( $self, $c, $id ) = @_;
-        my $precondition : Stash;
 
         my $precond_search = $c->model('TestrunDB')->resultset('Precondition')->find($id);
         if (not $precond_search) {
                 $c->response->body(qq(No precondition with id "$id" found in the database!));
                 return;
         }
-        $precondition = $precond_search->precondition_as_hash;
-        $precondition->{id} = $precond_search->id;
+        $c->stash->{precondition} = $precond_search->precondition_as_hash;
+        $c->stash->{precondition}{id} = $precond_search->id;
         return;
 }
 
