@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Reports::Web::Controller::Tapper::Testplan::Id::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Reports::Web::Controller::Tapper::Testplan::Id::VERSION = '4.0.4';
+  $Tapper::Reports::Web::Controller::Tapper::Testplan::Id::VERSION = '4.1.0';
 }
 
 use parent 'Tapper::Reports::Web::Controller::Base';
@@ -17,6 +17,14 @@ use Data::DPath 'dpath';
 use File::Basename 'basename';
 use YAML::Syck 'Load';
 
+sub auto :Private
+{
+        my ( $self, $c ) = @_;
+        $c->forward('/tapper/testplan/id/prepare_navi');
+}
+
+
+
 
 sub parse_testrun
 {
@@ -41,14 +49,14 @@ sub parse_testrun
 
 sub gen_testplan_overview
 {
-        my ($self, $yaml) = @_;
-        my $error : Stash;
+        my ($self, $c, $yaml) = @_;
+
         my @plans;
         eval {
                 @plans = Load($yaml);
         };
         if ($@) {
-                $error = "Broken YAML in testplan: $@";
+                $c->stash->{error} = "Broken YAML in testplan: $@";
                 return [];
         }
         my @testplan_elements;
@@ -67,32 +75,48 @@ sub gen_testplan_overview
 sub index :Path :Args(1)
 {
         my ( $self, $c, $instance_id ) = @_;
-        my $instance : Stash;
-        my $error    : Stash;
+
         $c->stash->{title} = "Testplan id $instance_id";
 
         my $inst_res = model('TestrunDB')->resultset('TestplanInstance')->find($instance_id);
         if (not $inst_res) {
-                $error = "No testplan with id $instance_id";
+                $c->stash->{error} = "No testplan with id $instance_id";
                 return;
         }
         my $util = Tapper::Reports::Web::Util::Testrun->new();
         my $testruns = $inst_res->testruns;
         my $testrunlist = $util->prepare_testrunlist($testruns);
 
-        $instance->{id}       = $inst_res->id;
-        $instance->{name}     = $inst_res->name || '[no name]';
-        $instance->{testruns} = $testrunlist;
-        $instance->{plan}     = $inst_res->evaluated_testplan;
-        $instance->{plan}     =~ s/^\n+//m;
-        $instance->{plan}     =~ s/\n+/\n/m;
-        $instance->{path}     = $inst_res->path;
-        $instance->{overview} = $self->gen_testplan_overview($instance->{plan});
-        $c->stash->{title} = "Testplan id $instance_id, ".$instance->{name};
+        $c->stash->{instance}{id}       = $inst_res->id;
+        $c->stash->{instance}{name}     = $inst_res->name || '[no name]';
+        $c->stash->{instance}{testruns} = $testrunlist;
+        $c->stash->{instance}{plan}     = $inst_res->evaluated_testplan;
+        $c->stash->{instance}{plan}     =~ s/^\n+//m;
+        $c->stash->{instance}{plan}     =~ s/\n+/\n/m;
+        $c->stash->{instance}{path}     = $inst_res->path;
+        $c->stash->{instance}{overview} = $self->gen_testplan_overview($c, $c->stash->{instance}{plan});
+        $c->stash->{title} = "Testplan id $instance_id, ".$c->stash->{instance}{name};
         return;
 }
 
+sub prepare_navi :Private
+{
+        my ( $self, $c, $id ) = @_;
 
+        # When showing testplans by ID no filters are active so we
+        # remove the wrong filters Testplan::prepare_navi already added
+        my @navi = grep {$_->{title} ne "Active Filters"} @{$c->stash->{navi}};
+        $c->stash->{navi} = \@navi;
+
+        push @{$c->stash->{navi}}, { title => 'Rerun this testplan',
+                       href  => "/tapper/testplan/$id/rerun",
+                       confirm => 'Do you want to reapply this test plan?',
+                     };
+        push @{$c->stash->{navi}}, { title => 'Delete this testplan',
+                       href  => "/tapper/testplan/$id/delete",
+                       confirm => "Do you want to delete this test plan?\nAll associated testruns will set to finished.",
+                     };
+}
 
 
 
