@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Reports::Web::Controller::Tapper::Testruns::IdList::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Reports::Web::Controller::Tapper::Testruns::IdList::VERSION = '4.0.4';
+  $Tapper::Reports::Web::Controller::Tapper::Testruns::IdList::VERSION = '4.1.0';
 }
 
 use 5.010;
@@ -15,11 +15,19 @@ use Tapper::Reports::Web::Util::Testrun;
 use parent 'Tapper::Reports::Web::Controller::Base';
 
 
+sub auto :Private
+{
+        my ( $self, $c ) = @_;
+        $c->forward('/tapper/testruns/idlist/prepare_navi');
+}
+
+
+
 sub index :Path :Args(1)
 {
         my ( $self, $c, $idlist ) = @_;
 
-        my %testrunlist : Stash = ();
+        %{$c->stash->{testrunlist}} = ();
         my $filter_condition;
 
         my @ids = split (qr/, */, $idlist);
@@ -37,10 +45,20 @@ sub index :Path :Args(1)
             order_by => 'me.id desc' }
           );
 
-        %testrunlist = (testruns => $util->prepare_testrunlist($testruns) );
+        %{$c->stash->{testrunlist}} = (testruns => $util->prepare_testrunlist($testruns) );
 
 }
 
+sub prepare_navi :Private
+{
+        my ( $self, $c, $id ) = @_;
+
+        # When showing test by ID no filters are active so we
+        # remove the wrong filters Testrun::prepare_navi already added
+        my @navi = grep {$_->{title} ne "Active Filters"} @{$c->stash->{navi}};
+        $c->stash->{navi} = \@navi;
+}
+
 
 
 1;
