@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Reports::Web::Util::Filter::Report::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Reports::Web::Util::Filter::Report::VERSION = '4.0.4';
+  $Tapper::Reports::Web::Util::Filter::Report::VERSION = '4.1.0';
 }
 
 
@@ -53,7 +53,7 @@ sub suite
                 $suite_id = $suite;
         } else {
                 my $suite_rs = $self->context->model('ReportsDB')->resultset('Suite')->search({name => $suite});
-                $suite_id = $suite_rs->first->id if $suite_rs->count;
+                $suite_id = $suite_rs->search({}, {rows => 1})->first->id if $suite_rs->count;
         }
 
         my @suites;
