@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Reports::Web::Util::Filter::Testrun::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Reports::Web::Util::Filter::Testrun::VERSION = '4.0.4';
+  $Tapper::Reports::Web::Util::Filter::Testrun::VERSION = '4.1.0';
 }
 
 
@@ -37,7 +37,7 @@ sub BUILD{
 sub host
 {
         my ($self, $filter_condition, $host) = @_;
-        my $host_result = model('TestrunDB')->resultset('Host')->search({name => $host})->first;
+        my $host_result = model('TestrunDB')->resultset('Host')->search({name => $host}, {rows => 1})->first;
 
         # (XXX) do we need to throw an error when someone filters for an
         # unknown host?
@@ -83,15 +83,14 @@ sub owner
 {
         my ($self, $filter_condition, $owner) = @_;
 
-        my $owner_result = model('TestrunDB')->resultset('User')->search({login => $owner})->first;
+        my $owner_result = model('TestrunDB')->resultset('Owner')->search({login => $owner}, {rows => 1})->first;
 
         if (not $owner_result) {
-                $filter_condition->{error} = "No user with login '$owner' found";
+                $filter_condition->{error} = "No owner with login '$owner' found";
                 return $filter_condition;
         }
 
-
-        $filter_condition->{early}->{owner_user_id} = $owner_result->id;
+        $filter_condition->{early}->{owner_id} = $owner_result->id;
 
         return $filter_condition;
 }
